#
# spec file for package opensaml
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libvers 12
%define pkgdocdir %{_docdir}/%{name}
Name:           opensaml
Version:        3.2.1
Release:        1.12
Summary:        Security Assertion Markup Language library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://wiki.shibboleth.net/confluence/display/OpenSAML/
Source0:        https://shibboleth.net/downloads/c++-opensaml/%{version}/%{name}-%{version}.tar.bz2
Source1:        https://shibboleth.net/downloads/c++-opensaml/%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Patch0:         opensaml-2.5.5-doxygen_timestamp.patch
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libboost_headers-devel
BuildRequires:  liblog4shib-devel >= 1.0.4
BuildRequires:  libxerces-c-devel >= 3.2
BuildRequires:  libxml-security-c-devel >= 2.0.0
BuildRequires:  libxmltooling-devel >= 3.1.0
BuildRequires:  pkgconfig

%description
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

%package -n opensaml-bin
Summary:        Utilities for OpenSAML library
Group:          Development/Libraries/C and C++

%description -n opensaml-bin
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package contains the utility programs.

%package -n libsaml%{libvers}
Summary:        Security Assertion Markup Language library
Group:          System/Libraries
Provides:       opensaml = %{version}-%{release}
Obsoletes:      opensaml < %{version}-%{release}

%description -n libsaml%{libvers}
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package contains just the shared library.

%package -n libsaml-devel
Summary:        OpenSAML development Headers
Group:          Development/Libraries/C and C++
Requires:       liblog4shib-devel >= 1.0.4
Requires:       libsaml%{libvers} = %{version}-%{release}
Requires:       libxerces-c-devel >= 3.2
Requires:       libxml-security-c-devel >= 2.0.0
Requires:       libxmltooling-devel >= 3.1.0
Provides:       opensaml-devel = %{version}-%{release}
Obsoletes:      opensaml-devel < %{version}-%{release}

%description -n libsaml-devel
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package includes files needed for development with OpenSAML.

%package -n opensaml-schemas
Summary:        OpenSAML schemas and catalog
Group:          Development/Libraries/C and C++

%description -n opensaml-schemas
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package includes XML schemas and related files.

%prep
%setup -q
%patch0 -p1

%build
# The default C++ standard used in GCC-11 is C++17,
# which does not support opensaml codebase.
CXXFLAGS="-std=c++11 %{optflags}"
export CXXFLAGS
%configure
%make_build

%install
make install DESTDIR=%{buildroot} pkgdocdir=%{pkgdocdir}
# Don't package unit tester if present.
rm -f %{buildroot}/%{_bindir}/samltest
rm -f %{buildroot}/%{_libdir}/libsaml.la

%check
%make_build check

%post -n libsaml%{libvers} -p /sbin/ldconfig
%postun -n libsaml%{libvers} -p /sbin/ldconfig

%files -n opensaml-bin
%{_bindir}/samlsign

%files -n libsaml%{libvers}
%{_libdir}/libsaml.so.*

%files -n opensaml-schemas
%dir %{_datadir}/xml/opensaml
%{_datadir}/xml/opensaml/*

%files -n libsaml-devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/opensaml.pc
%doc %{pkgdocdir}

%changelog
* Wed Dec  1 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 3.2.1:
  * No changelog provided
* Tue Jul 13 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 3.2.0:
  * [CPPOST-117] - SAML2PolicyTest testSAML2Policy: Test failed: Policy should have tripped on InResponseTo correlation
  * [CPPOST-118] - Metadata filter for adding UIInfo extensions
  * [CPPOST-119] - Discovery filter for inline logos
  * [CPPOST-121] - Deprecate and replace sensitive terms in APIs and components
- Update library version to 12
* Tue Dec  1 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 3.1.0
  * [CPPOST-111] - Assorted build system fixups
  * [CPPOST-114] - Add notion of profile to SecurityPolicy
  * [CPPOST-112] - Implement message correlation in SAML2 encoder/decoder
  * [CPPOST-115] - Add regular expression option to EntityAttributes filter
- Update library version to 11
- Run spec-cleaner
- Refresh opensaml-2.5.5-doxygen_timestamp.patch
* Wed Mar 20 2019 Kristýna Streitová <kstreitova@suse.com>
- update to 3.0.1
  * no changelog available
- requires libxmltooling-devel >= 3.0.1
* Tue Nov 27 2018 kstreitova@suse.com
- update to 3.0.0
  * [CPPOST-72] - Excessive CFLAGS included in installed pkgconfig
    file
  * [CPPOST-103] - Deprecate/remove old style metadata filter
    definitions
  * [CPPOST-104] - Rationalize logging names for Metadata Providers
  * [CPPOST-106] - Explicitly complain if ChainingMetadata Provider
    tries to install filters
  * [CPPOST-68] - Add per-entity observability for metadata
    providers
  * [CPPOST-98] - On-disk caching of dynamically acquired metadata
  * [CPPOST-108] - auto_ptr clea
- require libxerces-c-devel >= 3.2, libxml-security-c-devel >= 2.0.0
  and libxmltooling-devel >= 3.0.0
- update library soname from 9 to 10
* Wed Nov 15 2017 kstreitova@suse.com
- update to 2.6.1
  * [CPPOST-99] - DynamicMetadataProvider rejects metadata returned
    from MDQ associated with artifact profile
  * [CPPOST-100] - Assertions20SchemaValidator fails in case of
    EncryptedAttribute in Assertions
  * [CPPOST-105] - Dynamic metadata provider fails to install filt
  * fixes [bsc#1068685] [CVE-2017-16853]
* Thu Sep 21 2017 kstreitova@suse.com
- update to 2.6.0
  * [CPPOST-10] - Name Format Constants for Unspecified Are
    Misspelled
  * [CPPOST-85] - Dynamic metadata plugin race conditons / leaks
  * [CPPOST-93] - Source build fails to link properly against
    OpenSSL
  * [CPPOST-95] - Add MD RPI extension implementation to metadata
    classes.
  * [CPPOST-96] - EntityMatcher implementation based on RPI
    registrationAuthority extension
  * [CPPOST-97] - skip signature check on cached copy of verified
    metadata at restart
- now opensaml requires libxmltooling-devel >= 1.6.0
- update soname for libsaml from 8 to 9
- use https instead of http in Source
- run spec-cleaner
* Sat Feb 11 2017 jengelh@inai.de
- Update RPM groups and summary
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Aug  5 2015 mpluskal@suse.com
- Add gpg signature
* Tue Jul 28 2015 kstreitova@suse.com
- use spec-cleaner again
- fix Source address
- remove unused conditionals
* Mon Jul 27 2015 kstreitova@suse.com
- use spec-cleaner
- package cleaning
- add opensaml-2.5.5-doxygen_timestamp.patch to remove timestamps
  in a documentation generated by Doxygen and avoid RPMLINT warnings
  (file-contains-date-and-time).
* Fri Jul 24 2015 kstreitova@suse.com
- initial revision
